@@ -71,12 +71,18 @@ FAILEDOPERATION_USERINFONOMATCH = 'FailedOperation.UserInfoNoMatch'
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
+# 第三方接口失败。
+INTERNALERROR_API = 'InternalError.Api'
+
 # 缓存错误。
 INTERNALERROR_CACHE = 'InternalError.Cache'
 
 # 数据库异常。
 INTERNALERROR_DB = 'InternalError.Db'
 
+# 数据库连接出错。
+INTERNALERROR_DBCONNECTION = 'InternalError.DbConnection'
+
 # 数据库新增记录出错。
 INTERNALERROR_DBINSERT = 'InternalError.DbInsert'
 
@@ -95,9 +101,15 @@ INTERNALERROR_DEPENDSDB = 'InternalError.DependsDb'
 # 加密失败。
 INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'
 
+# Json序列化失败。
+INTERNALERROR_JSONMARSHAL = 'InternalError.JsonMarshal'
+
 # Pdf错误。
 INTERNALERROR_PDF = 'InternalError.Pdf'
 
+# 序列化错误。
+INTERNALERROR_SERIALIZE = 'InternalError.Serialize'
+
 # 系统错误，请稍后重试。
 INTERNALERROR_SYSTEM = 'InternalError.System'
 
@@ -146,6 +158,9 @@ INVALIDPARAMETER_COMPONENTVALUE = 'InvalidParameter.ComponentValue'
 # 不合法的模板查询类型，请检查后重试。
 INVALIDPARAMETER_CONTENTTYPE = 'InvalidParameter.ContentType'
 
+# 无效的自定义页卡模板，请检查后重试。
+INVALIDPARAMETER_CUSTOMSHOWMAP = 'InvalidParameter.CustomShowMap'
+
 # 数据已存在。
 INVALIDPARAMETER_DATAEXISTS = 'InvalidParameter.DataExists'
 
@@ -260,6 +275,12 @@ INVALIDPARAMETER_RESOURCETYPE = 'InvalidParameter.ResourceType'
 # 不合法的印章id，请检查印章id是够正确，并在修改后重试。
 INVALIDPARAMETER_SEALID = 'InvalidParameter.SealId'
 
+# 参数包含有敏感词
+INVALIDPARAMETER_SENSITIVE = 'InvalidParameter.Sensitive'
+
+# 签署控件参数不合法，请检查后重试。
+INVALIDPARAMETER_SIGNCOMPONENTS = 'InvalidParameter.SignComponents'
+
 # 参数Status不正确。
 INVALIDPARAMETER_STATUS = 'InvalidParameter.Status'
 
@@ -365,9 +386,15 @@ OPERATIONDENIED_CCUSERREPEAT = 'OperationDenied.CcUserRepeat'
 # 电子文档不可用，请稍后重试。
 OPERATIONDENIED_DOCUMENTNOAVAILABLE = 'OperationDenied.DocumentNoAvailable'
 
+# 此企业无该资源使用权限。
+OPERATIONDENIED_ERRNORESOURCEACCESS = 'OperationDenied.ErrNoResourceAccess'
+
 # 个人签署方不支持设置企业名称，请确认签署人类型后重试。
 OPERATIONDENIED_ERRNOSUPPORTINDIVIDUALHASORGANIZATIONNAME = 'OperationDenied.ErrNoSupportIndividualHasOrganizationName'
 
+# 文件已被删除，请联系客服处理。
+OPERATIONDENIED_FILEDELETED = 'OperationDenied.FileDeleted'
+
 # 文件与资源不匹配，请检查文件名与资源id数量以及对应关系，并在修改后重试。
 OPERATIONDENIED_FILENOMATCHRESOURCE = 'OperationDenied.FileNoMatchResource'
 
@@ -428,6 +455,9 @@ OPERATIONDENIED_NOVERIFY = 'OperationDenied.NoVerify'
 # 不属于企业超管或者法人。
 OPERATIONDENIED_NOTBELONGSUPERADMINORLEGALPERSON = 'OperationDenied.NotBelongSuperAdminOrLegalPerson'
 
+# 操作者权限不足。
+OPERATIONDENIED_OPERATORHASNOPERMISSION = 'OperationDenied.OperatorHasNoPermission'
+
 # 此社会信用编码未查询到结果，请检查后重试。
 OPERATIONDENIED_ORGUNIFORMSOCIALCREDITCODEERR = 'OperationDenied.OrgUniformSocialCreditCodeErr'
 
@@ -542,6 +572,9 @@ RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 请升级到对应版本后即可使用该接口。
+UNAUTHORIZEDOPERATION_NOPERMISSIONFEATURE = 'UnauthorizedOperation.NoPermissionFeature'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
